(*
 ***********************************************
 *	[imgctl.pas] Version 1.27
 *		For imgctl.dll version 1.27.
 *		Copyright (C) ruche.
 ***********************************************
 *)

unit imgctl;

(* {$DEFINE IMGCTL_RUNTIME} *)
(* {$DEFINE IMGCTL_TYPEDEF_NOTUSE} *)
{$ALIGN 4}

interface

uses Windows, SysUtils;

const
	(* Unit file support version *)
	IMGCTL_VERSION			: WORD = 127;
	IMGCTL_BETA				: WORD = 0;
	IMGCTL_VERSION_STRING	: LPCSTR = '1.27';

	(* PNGOPT flag Constants *)
	POF_COMPLEVEL		: DWORD = $00000001;
	POF_POF_FILTER		: DWORD = $00000002;
	POF_GAMMA			: DWORD = $00000004;
	POF_TRNSCOLOR		: DWORD = $00000008;
	POF_BACKCOLOR		: DWORD = $00000010;
	POF_TEXT			: DWORD = $00000020;
	POF_TEXTCOMP		: DWORD = $00000040;
	POF_INTERLACING		: DWORD = $00000080;
	POF_TIME			: DWORD = $00000100;
	POF_BACKPALETTE		: DWORD = $00010000;
	POF_TRNSPALETTE		: DWORD = $00020000;
	POF_TRNSALPHA		: DWORD = $00040000;

	(* PNGOPT filter Constants *)
	PO_FILTER_NONE		: DWORD = $00000008;
	PO_FILTER_SUB		: DWORD = $00000010;
	PO_FILTER_UP		: DWORD = $00000020;
	PO_FILTER_AVG		: DWORD = $00000040;
	PO_FILTER_PAETH		: DWORD = $00000080;
	PO_FILTER_ALL		: DWORD = $000000F8;

	(* PNGOPT gamma Constants *)
	PO_GAMMA_NORMAL		: DWORD = 45455;
	PO_GAMMA_WIN		: DWORD = 45455;
	PO_GAMMA_MAC		: DWORD = 55556;

	(* GIFOPT flag Constants *)
	GOF_LOGICAL			: DWORD = $00000001;
	GOF_TRNSCOLOR		: DWORD = $00000008;
	GOF_BACKCOLOR		: DWORD = $00000010;
	GOF_INTERLACING		: DWORD = $00000080;
	GOF_BACKPALETTE		: DWORD = $00010000;
	GOF_TRNSPALETTE		: DWORD = $00020000;
	GOF_LZWCLRCOUNT		: DWORD = $00080000;
	GOF_LZWNOTUSE		: DWORD = $00100000;
	GOF_BITCOUNT		: DWORD = $00200000;

	(* GIFANIOPT flag Constants *)
	GAF_LOGICAL			: DWORD = $00000001;
	GAF_BACKCOLOR		: DWORD = $00000010;
	GAF_LOOPCOUNT		: DWORD = $00000400;
	GAF_NOTANI			: DWORD = $00000800;

	(* GIFANISCENE flag Constants *)
	GSF_LOGICAL			: DWORD = $00000001;
	GSF_TRNSCOLOR		: DWORD = $00000008;
	GSF_INTERLACING		: DWORD = $00000080;
	GSF_TRNSPALETTE		: DWORD = $00020000;
	GSF_LZWCLRCOUNT		: DWORD = $00080000;
	GSF_LZWNOTUSE		: DWORD = $00100000;
	GSF_BITCOUNT		: DWORD = $00200000;
	GSF_DISPOSAL		: DWORD = $00001000;
	GSF_USERINPUT		: DWORD = $00002000;

	(* GIFANISCENE disposal methods Constants *)
	GS_DISP_NONE		: WORD = 0;
	GS_DISP_LEAVE		: WORD = 1;
	GS_DISP_BACK		: WORD = 2;
	GS_DISP_PREV		: WORD = 3;

	(* Image type Constants *)
	IMG_ERROR			: DWORD = $00FFFFFF;	// v1.12B9
	IMG_UNKNOWN			: DWORD = $00000000;
	IMG_BMP				: DWORD = $00000001;
	IMG_BITMAP			: DWORD = $00000001;
	IMG_DIB				: DWORD = $00000001;
	IMG_RLE				: DWORD = $00000001;
	IMG_JPEG			: DWORD = $00000002;
	IMG_JPE				: DWORD = $00000002;
	IMG_JPG				: DWORD = $00000002;
	IMG_EXIF			: DWORD = $00000002;	// v1.10B4
	IMG_PNG				: DWORD = $00000003;
	IMG_GIF				: DWORD = $00000004;
	IMG_TIFF			: DWORD = $00000005;
	IMG_TIF				: DWORD = $00000005;
	IMG_PIC				: DWORD = $00000006;
	IMG_MAG				: DWORD = $00000007;
	IMG_MAKI			: DWORD = $00000007;
	IMG_PCX				: DWORD = $00000008;

	(* Enough buffer size [v1.16B3] *)
	BUFSIZE_ENOUGH		: DWORD = $FFFFFFFF;

	(* Bitfield types *)
	RGB555_R			: DWORD = $00007C00;
	RGB555_G			: DWORD = $000003E0;
	RGB555_B			: DWORD = $0000001F;
	RGB565_R			: DWORD = $0000F800;
	RGB565_G			: DWORD = $000007E0;
	RGB565_B			: DWORD = $0000001F;
	RGB888_R			: DWORD = $00FF0000;
	RGB888_G			: DWORD = $0000FF00;
	RGB888_B			: DWORD = $000000FF;

	(* DIBto16BitEx & DIBto8Bit types [v1.10B4] *)
	TOBIT_DEFAULT		: DWORD = $00000000;
	TOBIT_ORG			: DWORD = $00100000;	// v1.10
	TOBIT_DIFF			: DWORD = $00000001;
	TOBIT_DIFFFS		: DWORD = $00000002;	// v1.10B5	// default
	TOBIT_DIFFJJN		: DWORD = $00000003;	// v1.10B5
	TOBIT_DIFFX			: DWORD = $00000101;	// v1.10B7
	TOBIT_DIFFXFS		: DWORD = $00000102;	// v1.10B7
	TOBIT_DIFFXJJN		: DWORD = $00000103;	// v1.10B7
	TOBIT_DIFFDX		: DWORD = $00000201;	// v1.10B8
	TOBIT_DIFFDXFS		: DWORD = $00000202;	// v1.10B8
	TOBIT_DIFFDXJJN		: DWORD = $00000203;	// v1.10B8

	(* DIBto8Bit flags *)
	TO8_DIV_RGB			: DWORD = $00000000;
	TO8_DIV_LIGHT		: DWORD = $00000001;
	TO8_SEL_CENTER		: DWORD = $00000000;
	TO8_SEL_AVGRGB		: DWORD = $00000100;
	TO8_SEL_AVGPIX		: DWORD = $00000200;
	TO8_PUT_RGB			: DWORD = $00000000;
	TO8_PUT_LIGHT		: DWORD = $00010000;
	TO8_PUT_YUV			: DWORD = $00020000;

	(* Resize flags [v1.12B] *)
	RESZ_SAME			: Integer = 0;
	RESZ_RATIO			: Integer = -1;

	(* Replace colors *)
	REP_R				: WORD = 0;
	REP_RED				: WORD = 0;
	REP_G				: WORD = 1;
	REP_GREEN			: WORD = 1;
	REP_B				: WORD = 2;
	REP_BLUE			: WORD = 2;

	(* Turn types *)
	TURN_90				: Integer = 90;
	TURN_180			: Integer = 180;
	TURN_270			: Integer = 270;

	(* Error codes [v1.07B2] *)
	ICERR_NONE			: DWORD = $00000000;
	ICERR_FILE_OPEN		: DWORD = $00010001;
	ICERR_FILE_READ		: DWORD = $00010002;
	ICERR_FILE_WRITE	: DWORD = $00010003;
	ICERR_FILE_TYPE		: DWORD = $00010004;	(* v1.07B3 *)
	ICERR_FILE_NULL		: DWORD = $00010005;	(* v1.07B3 *)
	ICERR_FILE_SEEK		: DWORD = $00010006;	(* v1.13B4 *)
	ICERR_FILE_SIZE		: DWORD = $00010007;	(* v1.16B3 *)
	ICERR_PARAM_NULL	: DWORD = $00020001;
	ICERR_PARAM_SIZE	: DWORD = $00020002;
	ICERR_PARAM_TYPE	: DWORD = $00020003;
	ICERR_PARAM_RANGE	: DWORD = $00020004;	(* v1.13 *)
	ICERR_MEM_ALLOC		: DWORD = $00030001;
	ICERR_MEM_SIZE		: DWORD = $00030002;	(* v1.16B3 *)
	ICERR_IMG_COMPRESS	: DWORD = $00040001;
	ICERR_IMG_RLESIZE	: DWORD = $00040002;
	ICERR_IMG_BITCOUNT	: DWORD = $00040003;	(* v1.12B3 *)
	ICERR_IMG_AREA		: DWORD = $00040004;	(* v1.12B3 *)
	ICERR_IMG_RLETOP	: DWORD = $00040005;	(* v1.12B3 *)
	ICERR_DIB_RLECOMP	: DWORD = $00050001;
	ICERR_DIB_RLEEXP	: DWORD = $00050002;
	ICERR_DIB_RLEBIT	: DWORD = $00050003;
	ICERR_DIB_NULL		: DWORD = $00050004;	(* v1.07B3 *)
	ICERR_DIB_UPPER16	: DWORD = $00050005;	(* v1.07B3 *)
	ICERR_DIB_AREAOUT	: DWORD = $00050006;	(* v1.10B *)
	ICERR_BMP_FILEHEAD	: DWORD = $00060001;
	ICERR_BMP_HEADSIZE	: DWORD = $00060002;
	ICERR_BMP_IMGSIZE	: DWORD = $00060003;
	ICERR_BMP_COMPRESS	: DWORD = $00060004;
	ICERR_RLE_TOPDOWN	: DWORD = $00070001;
	ICERR_RLE_DATASIZE	: DWORD = $00070002;
	ICERR_JPEG_LIBERR	: DWORD = $00080001;
	ICERR_PNG_LIBERR	: DWORD = $00090001;
	ICERR_PNG_NOALPHA	: DWORD = $00090002;	(* v1.12B5 *)
	ICERR_GIF_FILEHEAD	: DWORD = $000B0001;	(* v1.13B4 *)
	ICERR_GIF_BLOCK		: DWORD = $000B0002;	(* v1.13B4 *)
	ICERR_API_STRETCH	: DWORD = $000A0001;
	ICERR_API_SETMODE	: DWORD = $000A0002;
	ICERR_API_SECTION	: DWORD = $000A0003;	(* v1.09 *)
	ICERR_API_COMDC		: DWORD = $000A0004;	(* v1.09 *)
	ICERR_API_SELOBJ	: DWORD = $000A0005;	(* v1.09 *)
	ICERR_API_BITBLT	: DWORD = $000A0006;	(* v1.09 *)

type
	(* DIB data handle *)
	HDIB = Pointer;
	HDIBC = HDIB;
	PHDIB = ^HDIB;

	(* DIB image data structure [v1.08] *)
	IMGDATA = record
		dwbmiSize	: DWORD;
		dwDataSize	: DWORD;
		pbmi		: PBITMAPINFO;
		pData		: PBYTE;
	end;
	PIMGDATA = ^IMGDATA;
	LPIMGDATA = PIMGDATA;
	LPCIMGDATA = PIMGDATA;

	(* DIB paste information structure *)
	PASTEINFO = record
		colDest		: COLORREF;
		colSrc		: COLORREF;
		dwReserved	: DWORD;
		_lParam		: LPARAM;

		(* v1.10B *)
		rcArea		: TRect;
		lXDest		: Integer;
		lYDest		: Integer;
		lXSrc		: Integer;
		lYSrc		: Integer;
	end;
	PPASTEINFO = ^PASTEINFO;
	LPPASTEINFO = PPASTEINFO;
	LPCPASTEINFO = PPASTEINFO;

	(* DIB paste hook procedure *)
	PASTEPROC = function (
		lppi		: LPPASTEINFO
		)	: COLORREF; stdcall;

	(* Convert table structure [v1.12B3] *)
	icConvArray = array[0 .. 255] of Byte;
	CONVTABLE = record
		tblB		: icConvArray;
		tblG		: icConvArray;
		tblR		: icConvArray
	end;
	PCONVTABLE = ^CONVTABLE;
	LPCONVTABLE = PCONVTABLE;
	LPCCONVTABLE = PCONVTABLE;

	(* Repaint information structure *)
	REPAINTINFO = record
		colBefore	: COLORREF;
		colAfter	: COLORREF;
	end;
	PREPAINTINFO = ^REPAINTINFO;
	LPREPAINTINFO = PREPAINTINFO;
	LPCREPAINTINFO = PREPAINTINFO;

	(* PNGOPT structure *)
	PNGOPT = record
		dwFlag		: DWORD;
		wCompLevel	: WORD;

		wReserved	: WORD;		// v1.12B7

		dwFilter	: DWORD;
		dwGamma		: DWORD;
		clrTrans	: LPARAM;
		clrBack		: LPARAM;
		lpText		: LPSTR;

		dwReserved1	: DWORD;
		dwReserved2	: DWORD;
	end;
	LPPNGOPT = ^PNGOPT;
	LPCPNGOPT = LPPNGOPT;

	(* ߏ\ for PNGOPT *)
	icTransArray = array[0 .. 255] of Byte;
	PALTRANS = record
		trans		: icTransArray;
		dwNum		: DWORD;
	end;
	PPALTRANS = ^PALTRANS;
	LPPALTRANS = PPALTRANS;

	(* GIFOPT structure *)
	GIFOPT = record
		dwFlag		: DWORD;

		clrTrans	: LPARAM;
		clrBack		: LPARAM;

		wLogWidth	: WORD;
		wLogHeight	: WORD;
		wLogLeft	: WORD;
		wLogTop		: WORD;

		dwLzwCount	: DWORD;
		dwBitCount	: DWORD;
	end;
	LPGIFOPT = ^GIFOPT;
	LPCGIFOPT = LPGIFOPT;

	(* GIFANIOPT structure *)
	GIFANIOPT = record
		dwFlag		: DWORD;

		clrBack		: LPARAM;
		wLogWidth	: WORD;
		wLogHeight	: WORD;
		wLoopCount	: WORD;

		wReserved	: WORD;
	end;
	LPGIFANIOPT = ^GIFANIOPT;
	LPCGIFANIOPT = LPGIFANIOPT;

	(* GIFANISCENE structure *)
	GIFANISCENE = record
		dwFlag		: DWORD;

		clrTrans	: LPARAM;
		wLogLeft	: WORD;
		wLogTop		: WORD;
		dwLzwCount	: DWORD;
		dwBitCount	: DWORD;
		wDisposal	: WORD;

		wTime		: WORD;
		_hDIB		: HDIB;
	end;
	LPGIFANISCENE = ^GIFANISCENE;
	LPCGIFANISCENE = LPGIFANISCENE;

{$IF Defined(IMGCTL_RUNTIME) and not Defined(IMGCTL_TYPEDEF_NOTUSE)}

	(* Standard functions *)
	IMGCTLVERSION = function
			: WORD;
	IMGCTLBETA = function
			: WORD;
	IMGCTLERROR = function
			: DWORD;
	IMGCTLERRORCLEAR = procedure;
	POINTEROF = function (
		pvData				: Pointer
		)	: Pointer;
	GETIMAGETYPE = function (
		const lpImageFile	: LPCSTR;
		pdwFlag				: PDWORD
		)	: DWORD;
	GETIMAGEMTYPE = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD;
		pdwFlag				: PDWORD
		)	: DWORD;
	TODIB = function (
		const lpImageFile	: LPCSTR
		)	: HDIB;
	MTODIB = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD
		)	: HDIB;

	(* DIB functions *)
	DELETEDIB = function (
		_hDIB				: HDIB
		)	: BOOL;
	HEADDIB = function (
		const _hDIB			: HDIBC;
		pbmih				: PBITMAPINFOHEADER
		)	: BOOL;
	PALETTEDIB = function (
		const _hDIB			: HDIBC;
		rgbColors			: PRGBQUAD;
		dwClrNum			: DWORD
		)	: DWORD;
	PIXELDIB = function (
		const _hDIB			: HDIBC;
		lXPos				: Integer;
		lYPos				: Integer
		)	: COLORREF;
	COLORDIB = function (
		const _hDIB			: HDIBC
		)	: DWORD;
	GETDIB = function (
		const _hDIB			: HDIBC;
		pbmi				: PBITMAPINFO;
		pdwbmiSize			: PDWORD;
		pvData				: Pointer;
		pdwDataSize			: PDWORD
		)	: BOOL;
	MAPDIB = function (
		_hDIB				: HDIB;
		var ppbmi			: PBITMAPINFO;
		pdwbmiSize			: PDWORD;
		var ppvData			: Pointer;
		pdwDataSize			: PDWORD
		)	: BOOL;
	DATADIB = function (
		_hDIB				: HDIB
		)	: LPIMGDATA;
	CREATEDIB = function (
		const pbmi			: PBITMAPINFO;
		const pvData		: Pointer
		)	: HDIB;
	COPYDIB = function (
		const _hDIB			: HDIBC
		)	: HDIB;
	CUTDIB = function (
		const _hDIB			: HDIBC;
		lX					: Integer;
		lY					: Integer;
		lWidth				: Integer;
		lHeight				: Integer
		)	: HDIB;
	TURNDIB = function (
		_hDIB				: HDIB;
		iTurnType			: Integer
		)	: BOOL;
	DIBTO24BIT = function (
		_hDIB				: HDIB
		)	: BOOL;
	DIBTO16BIT = function (
		_hDIB				: HDIB;
		const dwBitFields	: PDWORD
		)	: BOOL;
	DIBTO16BITEX = function (
		_hDIB				: HDIB;
		const dwBitFirlds	: PDWORD;
		dwType				: DWORD
		)	: BOOL;
	DIBTO8BIT = function (
		_hDIB				: HDIB;
		dwFlags				: DWORD;
		dwType				: DWORD
		)	: BOOL;
	(* 24Bit DIB functions *)
	PASTEDIB = function (
		_hDIBDest			: HDIB;
		lXDest				: Integer;
		lYDest				: Integer;
		lWidth				: Integer;
		lHeight				: Integer;
		_hDIBSrc			: HDIBC;
		lXSrc				: Integer;
		lYSrc				: Integer;
		pfnPasteProc		: PASTEPROC;
		_lParam				: LPARAM
		)	: BOOL;
	RESIZEDIB = function (
		_hDIB				: HDIB;
		lWidth				: Integer;
		lHeight				: Integer
		)	: BOOL;
	TURNDIBEX = function (
		_hDIB				: HDIB;
		lAngle				: Integer;
		clrBack				: COLORREF
		)	: BOOL;

	(* RLE-DIB functions *)
	ISRLE = function (
		const _hDIB			: HDIBC
		)	: BOOL;
	DIBTORLE = function (
		_hDIB				: HDIB
		)	: BOOL;
	RLETODIB = function (
		_hRLE				: HDIB
		)	: BOOL;

	(* Bitmap functions *)
	DIBTOBMP = function (
		const lpBmpFile		: LPCSTR;
		const _hDIB			: HDIBC
		)	: BOOL;
	BMPTODIB = function (
		const lpBmpFile		: LPCSTR
		)	: HDIB;
	BMPMTODIB = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD
		)	: HDIB;

	(* JPEG functions *)
	DIBTOJPG = function (
		const lpJpegFile	: LPCSTR;
		const _hDIB			: HDIBC;
		iQuality			: Integer;
		bProgression		: BOOL
		)	: BOOL;
	JPGTODIB = function (
		const lpJpegFile	: LPCSTR
		)	: HDIB;
	JPGMTODIB = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD
		)	: HDIB;

	(* PNG functions *)
	DIBTOPNG = function (
		const lpPngFile		: LPCSTR;
		const _hDIB			: HDIBC;
		bInterlacing		: BOOL
		)	: BOOL;
	DIBTOPNGEX = function (
		const lpPngFile		: LPCSTR;
		const _hDIB			: HDIBC;
		const pPngOpt		: LPCPNGOPT
		)	: BOOL;
	PNGTODIB = function (
		const lpPngFile		: LPCSTR
		)	: HDIB;
	PNGMTODIB = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD
		)	: HDIB;
	PNGATODIB = function (
		const lpPngFile		: LPCSTR
		)	: HDIB;
	PNGMATODIB = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD
		)	: HDIB;
	INFOPNG = function (
		const lpPngFile		: LPCSTR;
		pPngOpt				: LPPNGOPT;
		pbmi				: PBITMAPINFO;
		dwbmiSize			: DWORD
		)	: BOOL;
	INFOPNGM = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD;
		pPngOpt				: LPPNGOPT;
		pbmi				: PBITMAPINFO;
		dwbmiSize			: DWORD
		)	: HDIB;

	(* GIF functions *)
	DIBTOGIF = function (
		const lpGifFile		: LPCSTR;
		const _hDIB			: HDIBC;
		bInterlacing		: BOOL
		)	: BOOL;
	DIBTOGIFEX = function (
		const lpGifFile		: LPCSTR;
		const _hDIB			: HDIBC;
		const pGifOpt		: LPCGIFOPT
		)	: BOOL;
	DIBTOGIFANI = function (
		const lpGifFile		: LPCSTR;
		const hDIBs			: PHDIB;
		dwCount				: DWORD;
		wTime				: WORD
		)	: BOOL;
	DIBTOGIFANIEX = function (
		const lpGifFile		: LPCSTR;
		const aniScenes		: LPGIFANISCENE;
		dwCount				: DWORD;
		const pGifAniOpt	: LPCGIFANIOPT
		)	: BOOL;
	GIFTODIB = function (
		const lpGifFile		: LPCSTR
		)	: HDIB;
	GIFMTODIB = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD
		)	: HDIB;
	GIFTODIBEX = function (
		const lpGifFile		: LPCSTR;
		pGifOpt				: LPGIFOPT
		)	: HDIB;
	GIFMTODIBEX = function (
		const pBuffer		: Pointer;
		dwBufSize			: DWORD;
		pGifOpt				: LPGIFOPT
		)	: HDIB;

	(* Filter functions *)
	GRAYDIB = function (
		_hDIB				: HDIB;
		wStrength			: WORD
		)	: BOOL;
	REPLACEDIB = function (
		_hDIB				: HDIB;
		rTo					: WORD;
		gTo					: WORD;
		bTo					: WORD
		)	: BOOL;
	REPAINTDIB = function (
		_hDIB				: HDIB;
		repis				: LPCREPAINTINFO;
		dwRepaintNum		: DWORD
		)	: BOOL;
	TABLEDIB = function (
		_hDIB				: HDIB;
		ptable				: LPCCONVTABLE
		)	: BOOL;
	(* Convert table functions *)
	TONEDIB = function (
		_hDIB				: HDIB;
		rMove				: SHORT;
		gMove				: SHORT;
		bMove				: SHORT
		)	: BOOL;
	SHADEDIB = function (
		_hDIB				: HDIB;
		rMul				: DWORD;
		gMul				: DWORD;
		bMul				: DWORD
		)	: BOOL;
	GAMMADIB = function (
		_hDIB				: HDIB;
		rGma				: WORD;
		gGma				: WORD;
		bGma				: WORD
		)	: BOOL;
	CONTRASTDIB = function (
		_hDIB				: HDIB;
		rStr				: SHORT;
		gStr				: SHORT;
		bStr				: SHORT
		)	: BOOL;

	(* Device context functions *)
	DIBTODC = function (
		_hdc				: HDC;
		nXDest				: Integer;
		nYDest				: Integer;
		nWidth				: Integer;
		nHeight				: Integer;
		const _hDIB			: HDIBC;
		nXSrc				: Integer;
		nYSrc				: Integer;
		dwRop				: DWORD
		)	: BOOL;
	DIBTODCEX = function (
		_hdc				: HDC;
		nXDest				: Integer;
		nYDest				: Integer;
		nDestWidth			: Integer;
		nDestHeight			: Integer;
		const _hDIB			: HDIBC;
		nXSrc				: Integer;
		nYSrc				: Integer;
		nSrcWidth			: Integer;
		nSrcHeight			: Integer;
		dwRop				: DWORD
		)	: BOOL;
	DIBTODCEX2 = function (
		_hdc				: HDC;
		nXDest				: Integer;
		nYDest				: Integer;
		nDestWidth			: Integer;
		nDestHeight			: Integer;
		const _hDIB			: HDIBC;
		nXSrc				: Integer;
		nYSrc				: Integer;
		nSrcWidth			: Integer;
		nSrcHeight			: Integer;
		dwRop				: DWORD;
		iStretchMode		: Integer
		)	: BOOL;
	DCTODIB = function (
		_hdc				: HDC;
		lXSrc				: Integer;
		lYSrc				: Integer;
		lWidth				: Integer;
		lHeight				: Integer
		)	: HDIB;
	(* for older than v1.08 *)
	DIBDIBITS = DIBTODC;
	DIBSTRETCHDIBITS = DIBTODCEX;
	DIBSTRETCHDIBITS2 = DIBTODCEX2;

{$ELSEIF not Defined(IMGCTL_RUNTIME)}

(* Standard functions *)
function ImgctlVersion
		: WORD; stdcall; external 'imgctl.dll';
function ImgctlBeta
		: WORD; stdcall; external 'imgctl.dll';
function ImgctlError
		: DWORD; stdcall; external 'imgctl.dll';
procedure ImgctlErrorClear; stdcall; external 'imgctl.dll';
function PointerOf (
	pvData				: Pointer
	)	: Pointer; stdcall; external 'imgctl.dll';
function GetImageType (
	const lpImageFile	: LPCSTR;
	pdwFlag				: PDWORD
	)	: DWORD; stdcall; external 'imgctl.dll';
function GetImageMType (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD;
	pdwFlag				: PDWORD
	)	: DWORD; stdcall; external 'imgctl.dll';
function ToDIB(
	const lpImageFile	: LPCSTR
	)	: HDIB; stdcall; external 'imgctl.dll';
function MtoDIB(
	const pBuffer		: Pointer;
	dwBufSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';

(* DIB functions *)
function DeleteDIB (
	_hDIB				: HDIB
	)	: BOOL; stdcall; external 'imgctl.dll';
function HeadDIB (
	const _hDIB			: HDIBC;
	pbmih				: PBITMAPINFOHEADER
	)	: BOOL; stdcall; external 'imgctl.dll';
function PaletteDIB (
	const _hDIB			: HDIBC;
	rgbColors			: PRGBQUAD;
	dwClrNum			: DWORD
	)	: DWORD; stdcall; external 'imgctl.dll';
function PixelDIB (
	const _hDIB			: HDIBC;
	lXPos				: Integer;
	lYPos				: Integer
	)	: COLORREF; stdcall; external 'imgctl.dll';
function ColorDIB (
	const _hDIB			: HDIBC
	)	: DWORD; stdcall; external 'imgctl.dll';
function GetDIB (
	const _hDIB			: HDIBC;
	pbmi				: PBITMAPINFO;
	pdwbmiSize			: PDWORD;
	pvData				: Pointer;
	pdwDataSize			: PDWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function MapDIB (
	_hDIB				: HDIB;
	var ppbmi			: PBITMAPINFO;
	pdwbmiSize			: PDWORD;
	var ppvData			: Pointer;
	pdwDataSize			: PDWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DataDIB (
	_hDIB				: HDIB
	)	: LPIMGDATA; stdcall; external 'imgctl.dll';
function CreateDIB (
	const pbmi			: PBITMAPINFO;
	const pvData		: Pointer
	)	: HDIB; stdcall; external 'imgctl.dll';
function CopyDIB (
	const _hDIB			: HDIBC
	)	: HDIB; stdcall; external 'imgctl.dll';
function CutDIB (
	const _hDIB			: HDIBC;
	lX					: Integer;
	lY					: Integer;
	lWidth				: Integer;
	lHeight				: Integer
	)	: HDIB; stdcall; external 'imgctl.dll';
function TurnDIB (
	_hDIB				: HDIB;
	iTurnType			: Integer
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBto24Bit (
	_hDIB				: HDIB
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBto16Bit (
	_hDIB				: HDIB;
	const dwBitFields	: PDWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBto16BitEx (
	_hDIB				: HDIB;
	const dwBitFields	: PDWORD;
	dwType				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBto8Bit (
	_hDIB				: HDIB;
	dwFlags				: DWORD;
	dwType				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
(* 24Bit DIB functions *)
function PasteDIB (
	_hDIBDest			: HDIB;
	lXDest				: Integer;
	lYDest				: Integer;
	lWidth				: Integer;
	lHeight				: Integer;
	_hDIBSrc			: HDIBC;
	lXSrc				: Integer;
	lYSrc				: Integer;
	pfnPasteProc		: PASTEPROC;
	_lParam				: LPARAM
	)	: BOOL; stdcall; external 'imgctl.dll';
function ResizeDIB (
	_hDIB				: HDIB;
	lWidth				: Integer;
	lHeight				: Integer
	)	: BOOL; stdcall; external 'imgctl.dll';
function TurnDIBex (
	_hDIB				: HDIB;
	lAngle				: Integer;
	clrBack				: COLORREF
	)	: BOOL; stdcall; external 'imgctl.dll';

(* RLE-DIB functions *)
function IsRLE (
	const _hDIB			: HDIBC
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoRLE (
	_hDIB				: HDIB
	)	: BOOL; stdcall; external 'imgctl.dll';
function RLEtoDIB (
	_hRLE				: HDIB
	)	: BOOL; stdcall; external 'imgctl.dll';

(* Bitmap functions *)
function DIBtoBMP (
	const lpBmpFile		: LPCSTR;
	const _hDIB			: HDIBC
	)	: BOOL; stdcall; external 'imgctl.dll';
function BMPtoDIB (
	const lpBmpFile		: LPCSTR
	)	: HDIB; stdcall; external 'imgctl.dll';
function BMPMtoDIB (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';

(* JPEG functions *)
function DIBtoJPG (
	const lpJpegFile	: LPCSTR;
	const _hDIB			: HDIBC;
	iQuality			: Integer;
	bProgression		: BOOL
	)	: BOOL; stdcall; external 'imgctl.dll';
function JPGtoDIB (
	const lpJpegFile	: LPCSTR
	)	: HDIB; stdcall; external 'imgctl.dll';
function JPGMtoDIB (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';

(* PNG functions *)
function DIBtoPNG (
	const lpPngFile		: LPCSTR;
	const _hDIB			: HDIBC;
	bInterlacing		: BOOL
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoPNGex (
	const lpPngFile		: LPCSTR;
	const _hDIB			: HDIBC;
	const pPngOpt		: LPCPNGOPT
	)	: BOOL; stdcall; external 'imgctl.dll';
function PNGtoDIB (
	const lpPngFile		: LPCSTR
	)	: HDIB; stdcall; external 'imgctl.dll';
function PNGMtoDIB (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';
function PNGAtoDIB (
	const lpPngFile		: LPCSTR
	)	: HDIB; stdcall; external 'imgctl.dll';
function PNGMAtoDIB (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';
function InfoPNG (
	const lpPngFile		: LPCSTR;
	pPngOpt				: LPPNGOPT;
	pbmi				: PBITMAPINFO;
	dwbmiSize			: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function InfoPNGM (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD;
	pPngOpt				: LPPNGOPT;
	pbmi				: PBITMAPINFO;
	dwbmiSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';

(* GIF functions *)
function DIBtoGIF (
	const lpGifFile		: LPCSTR;
	const _hDIB			: HDIBC;
	bInterlacing		: BOOL
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoGIFex (
	const lpGifFile		: LPCSTR;
	const _hDIB			: HDIBC;
	const pGifOpt		: LPCGIFOPT
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoGIFAni (
	const lpGifFile		: LPCSTR;
	const hDIBs			: PHDIB;
	dwCount				: DWORD;
	wTime				: WORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoGIFAniEx (
	const lpGifFile		: LPCSTR;
	const aniScenes		: LPGIFANISCENE;
	dwCount				: DWORD;
	const pGifAniOpt	: LPCGIFANIOPT
	)	: BOOL; stdcall; external 'imgctl.dll';
function GIFtoDIB (
	const lpGifFile		: LPCSTR
	)	: HDIB; stdcall; external 'imgctl.dll';
function GIFMtoDIB (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD
	)	: HDIB; stdcall; external 'imgctl.dll';
function GIFtoDIBex (
	const lpGifFile		: LPCSTR;
	pGifOpt				: LPGIFOPT
	)	: HDIB; stdcall; external 'imgctl.dll';
function GIFMtoDIBex (
	const pBuffer		: Pointer;
	dwBufSize			: DWORD;
	pGifOpt				: LPGIFOPT
	)	: HDIB; stdcall; external 'imgctl.dll';

(* Filter functions *)
function GrayDIB (
	_hDIB				: HDIB;
	wStrength			: WORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function ReplaceDIB (
	_hDIB				: HDIB;
	rTo					: WORD;
	gTo					: WORD;
	bTo					: WORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function RepaintDIB (
	_hDIB				: HDIB;
	const repis			: LPCREPAINTINFO;
	dwRepaintNum		: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function TableDIB (
	_hDIB				: HDIB;
	const ptable		: LPCCONVTABLE
	)	: BOOL; stdcall; external 'imgctl.dll';
(* Convert table functions *)
function ToneDIB (
	_hDIB				: HDIB;
	rMove				: SHORT;
	gMove				: SHORT;
	bMove				: SHORT
	)	: BOOL; stdcall; external 'imgctl.dll';
function ShadeDIB (
	_hDIB				: HDIB;
	rMul				: DWORD;
	gMul				: DWORD;
	bMul				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function GammaDIB (
	_hDIB				: HDIB;
	rGma				: WORD;
	gGma				: WORD;
	bGma				: WORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function ContrastDIB (
	_hDIB				: HDIB;
	rStr				: SHORT;
	gStr				: SHORT;
	bStr				: SHORT
	)	: BOOL; stdcall; external 'imgctl.dll';

(* Device context functions *)
function DIBtoDC (
	_hdc				: HDC;
	nXDest				: Integer;
	nYDest				: Integer;
	nWidth				: Integer;
	nHeight				: Integer;
	const _hDIB			: HDIBC;
	nXSrc				: Integer;
	nYSrc				: Integer;
	dwRop				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoDCex (
	_hdc				: HDC;
	nXDest				: Integer;
	nYDest				: Integer;
	nDestWidth			: Integer;
	nDestHeight			: Integer;
	const _hDIB			: HDIBC;
	nXSrc				: Integer;
	nYSrc				: Integer;
	nSrcWidth			: Integer;
	nSrcHeight			: Integer;
	dwRop				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBtoDCex2 (
	_hdc				: HDC;
	nXDest				: Integer;
	nYDest				: Integer;
	nDestWidth			: Integer;
	nDestHeight			: Integer;
	const _hDIB			: HDIBC;
	nXSrc				: Integer;
	nYSrc				: Integer;
	nSrcWidth			: Integer;
	nSrcHeight			: Integer;
	dwRop				: DWORD;
	iStretchMode		: Integer
	)	: BOOL; stdcall; external 'imgctl.dll';
function DCtoDIB (
	_hdc				: HDC;
	lXSrc				: Integer;
	lYSrc				: Integer;
	lWidth				: Integer;
	lHeight				: Integer
	)	: HDIB; stdcall; external 'imgctl.dll';
(* for older than v1.08 *)
function DIBDIBits (
	_hdc				: HDC;
	nXDest				: Integer;
	nYDest				: Integer;
	nWidth				: Integer;
	nHeight				: Integer;
	const _hDIB			: HDIBC;
	nXSrc				: Integer;
	nYSrc				: Integer;
	dwRop				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBStretchDIBits (
	_hdc				: HDC;
	nXDest				: Integer;
	nYDest				: Integer;
	nDestWidth			: Integer;
	nDestHeight			: Integer;
	const _hDIB			: HDIBC;
	nXSrc				: Integer;
	nYSrc				: Integer;
	nSrcWidth			: Integer;
	nSrcHeight			: Integer;
	dwRop				: DWORD
	)	: BOOL; stdcall; external 'imgctl.dll';
function DIBStretchDIBits2 (
	_hdc				: HDC;
	nXDest				: Integer;
	nYDest				: Integer;
	nDestWidth			: Integer;
	nDestHeight			: Integer;
	const _hDIB			: HDIBC;
	nXSrc				: Integer;
	nYSrc				: Integer;
	nSrcWidth			: Integer;
	nSrcHeight			: Integer;
	dwRop				: DWORD;
	iStretchMode		: Integer
	)	: BOOL; stdcall; external 'imgctl.dll';

{$IFEND}

Implementation

end.